package com.hrss.hrm.dataCollect.rest;

package ..deTemp.1731384779258;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.hrss.base.vo.Ab01Vo;
import com.hrss.base.vo.DataCollectAc01Vo;
import com.hrss.base.vo.DataCollectCc20Vo;
import com.hrss.base.vo.DataCollectCc21Vo;
import com.hrss.base.vo.DataCollectMemberVo;
import com.hrss.common.rest.AbstractBaseRestService;
import com.hrss.dubbo.api.DubboCommonRpcService;
import com.hrss.exception.BusinessException;
import com.hrss.hrm.api.SpringContextUtil;
import com.hrss.hrm.dataCollect.service.read.DataCollectCompanyReadService;
import com.hrss.hrm.dataCollect.service.read.DataCollectPersonalReadService;
import com.hrss.hrm.dataCollect.service.write.DataCollectCompanyWriteService;
import com.hrss.hrm.dataCollect.service.write.DataCollectPersonalWriteService;
import com.hrss.hrm.vo.Cb21Vo;
import com.hrss.util.AppAssert;
import com.yinhai.ta404.core.restservice.annotation.RestService;
import com.yinhai.ta404.core.restservice.resultbean.DefaultResultBeanImpl;
import com.yinhai.ta404.core.restservice.resultbean.ResultBean;
import com.yinhai.ta404.core.safe.passwordutil.gm.Sm2Util;
import com.yinhai.ta404.core.utils.JsonFactory;
import com.yinhai.ta404.core.utils.ValidateUtil;
import io.swagger.annotations.Api;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.Set;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.validation.ConstraintViolation;
import javax.validation.Valid;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.PostMapping;

@RestService({"dataCollect"})
@Valid
@Api(tags = {"数据归集接口"}, value = "DataCollectRestService")
public class DataCollectRestService extends AbstractBaseRestService {
  private static final Logger log = LoggerFactory.getLogger(com.hrss.hrm.dataCollect.rest.DataCollectRestService.class);
  
  @Resource
  private DataCollectPersonalReadService dataCollectPersonalReadService;
  
  @Resource
  private DataCollectPersonalWriteService dataCollectPersonalWriteService;
  
  @Resource
  private DataCollectCompanyReadService dataCollectCompanyReadService;
  
  @Resource
  private DataCollectCompanyWriteService dataCollectCompanyWriteService;
  
  @PostMapping({"callService"})
  public ResultBean callService(String methodName, String eData) throws Exception {
    Method method;
    AppAssert.notEmpty(methodName, "方法名称不能为空");
    AppAssert.notEmpty(eData, "加密参数列表不能为空");
    String decrypt = Sm2Util.decrypt(Sm2Util.pem2PrivateKey("/sm2/pri.key.pem"), eData);
    Map params = (Map)JsonFactory.json2bean(decrypt, Map.class);
    dznumCheck(params.get("dznum"));
    Class<?> clazz = SpringContextUtil.getBean("dataCollectRestService").getClass();
    Object clazzBean = SpringContextUtil.getBean("dataCollectRestService");
    try {
      Optional<Method> first = Arrays.<Method>stream(clazz.getMethods()).filter(m -> m.getName().equalsIgnoreCase(methodName)).findFirst();
      if (!first.isPresent())
        throw new ReflectiveOperationException("no method"); 
      method = first.get();
    } catch (Throwable e) {
      throw new RuntimeException("该服务中无该方法，无法进行通用调用！");
    } 
    if (ValidateUtil.isEmpty(method))
      throw new RuntimeException("该服务中无该方法，无法进行通用调用！"); 
    String[] parameterNames = parameterDiscover.getParameterNames(method);
    Class[] parameterTypes = method.getParameterTypes();
    Map<Integer, Object> list = new HashMap<>(parameterTypes.length);
    for (int i = 0; i < parameterNames.length; i++) {
      DubboCommonRpcService.BaseDataResult baseData = DubboCommonRpcService.getBaseData(clazz, params.get(parameterNames[i]));
      if (baseData.isBase) {
        list.put(Integer.valueOf(i), baseData.aClass);
      } else {
        list.put(Integer.valueOf(i), (new JSONObject(params)).toJavaObject(parameterTypes[i]));
      } 
    } 
    Object o = list.isEmpty() ? method.invoke(clazzBean, new Object[0]) : method.invoke(clazzBean, list.values().toArray());
    ResultBean resultBean = getResult();
    String resultEData = JsonFactory.bean2json(resultBean.getData());
    resultEData = Sm2Util.encrypt(Sm2Util.pem2PublicKey("/sm2/pub.key.pem"), resultEData);
    DefaultResultBeanImpl defaultResultBean = new DefaultResultBeanImpl();
    defaultResultBean.addField("data", resultEData);
    return (ResultBean)defaultResultBean;
  }
  
  @PostMapping({"accountSync"})
  public ResultBean accountSync(DataCollectMemberVo dataCollectMemberVo, DataCollectAc01Vo dataCollectAc01Vo) {
    checkNotNull(dataCollectMemberVo);
    checkNotNull(dataCollectAc01Vo);
    Map<Object, Object> resultMap = new HashMap<>();
    DataCollectMemberVo member = this.dataCollectPersonalReadService.memberExists(dataCollectMemberVo);
    DataCollectAc01Vo ac01 = this.dataCollectPersonalReadService.personExists(dataCollectAc01Vo);
    if (!ValidateUtil.isEmpty(member)) {
      if (!ValidateUtil.isEmpty(ac01)) {
        if (ac01.getAac001().compareTo(member.getAac001()) != 0)
          throw new BusinessException("当前手机号绑定过其他人员信息，无法再次注册!"); 
        resultMap.put("aac001", ac01.getAac001());
        resultMap.put("user_id", member.getUser_id());
        setData(resultMap, true);
      } else {
        throw new BusinessException("当前手机号已经注册绑定其他人员信息，无法再次注册!");
      } 
    } else {
      dataCollectMemberVo.setUser_name(dataCollectMemberVo.getPhone_mob());
      dataCollectMemberVo.setReg_time(getSysDate());
      dataCollectMemberVo.setUser_status("1");
      dataCollectMemberVo.setAab085("1");
      dataCollectMemberVo.setYae100("31");
      if (!ValidateUtil.isEmpty(ac01)) {
        dataCollectMemberVo.setAac001(ac01.getAac001());
        resultMap.put("aac001", ac01.getAac001());
        resultMap.put("user_id", this.dataCollectPersonalWriteService.insertMember(dataCollectMemberVo));
        setData(resultMap, true);
      } else {
        setData(this.dataCollectPersonalWriteService.insertMemberAndAC01(dataCollectMemberVo, dataCollectAc01Vo), true);
      } 
    } 
    return getResult();
  }
  
  @PostMapping({"hrBinding"})
  public ResultBean hrBinding(Ab01Vo ab01Vo) {
    AppAssert.notEmpty(ab01Vo.getAab004(), "单位名称不能为空");
    AppAssert.notEmpty(ab01Vo.getAab998(), "统一社会信用代码不能为空");
    AppAssert.notEmpty(ab01Vo.getAab022(), "所属行业不能为空");
    AppAssert.notEmpty(ab01Vo.getAab301(), "单位注册地行政区划代码不能为空");
    AppAssert.notEmpty(ab01Vo.getAab019(), "企业类型不能为空");
    AppAssert.notEmpty(ab01Vo.getAab056(), "企业规模不能为空");
    AppAssert.notEmpty(ab01Vo.getAab536(), "是否规上企业不能为空");
    AppAssert.notEmpty(ab01Vo.getUser_id(), "用户流水号不能为空");
    AppAssert.notEmpty(ab01Vo.getAac001(), "个人主键不能为空");
    AppAssert.notEmpty(ab01Vo.getYae412(), "经办人员编号不能为空");
    Map resultMap = this.dataCollectCompanyWriteService.hrBinding(ab01Vo);
    setData("data", resultMap);
    return getResult();
  }
  
  @PostMapping({"resumeSync"})
  public ResultBean resumeSync(DataCollectCc20Vo dataCollectCc20Vo, DataCollectCc21Vo dataCollectCc21Vo) {
    checkNotNull(dataCollectCc20Vo);
    checkNotNull(dataCollectCc21Vo);
    DataCollectCc20Vo cc20Exists = this.dataCollectPersonalReadService.resumeExists(dataCollectCc20Vo);
    Map<Object, Object> resultMap = new HashMap<>();
    if (ValidateUtil.isEmpty(cc20Exists)) {
      setData(this.dataCollectPersonalWriteService.insertCc20AndCc21(dataCollectCc20Vo, dataCollectCc21Vo), true);
    } else {
      this.dataCollectPersonalWriteService.updateCc20AndCc21(dataCollectCc20Vo, dataCollectCc21Vo);
      resultMap.put("acc200", dataCollectCc20Vo.getAcc200());
      resultMap.put("acc210", dataCollectCc21Vo.getAcc210());
      setData(resultMap, true);
    } 
    return getResult();
  }
  
  @PostMapping({"releaseJob"})
  public ResultBean releaseJob(Cb21Vo cb21Vo) {
    AppAssert.notEmpty(cb21Vo.getAab001(), "单位主键不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb213(), "职位名称不能为空");
    AppAssert.notEmpty(cb21Vo.getAca111(), "职位编码不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb21g(), "招聘总人数不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb216(), "职位描述不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb215(), "工作地址行政区划代码不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb21t(), "薪资类型不能为空");
    if ("1".equals(cb21Vo.getAcb21t()))
      AppAssert.notEmpty(cb21Vo.getAcb21h(), "最低薪资不能为空"); 
    AppAssert.notEmpty(cb21Vo.getAcb21j(), "最高薪资不能为空");
    AppAssert.notEmpty(cb21Vo.getAcb00r(), "职位亮点不能为空");
    AppAssert.notEmpty(cb21Vo.getYae412(), "经办人员编号不能为空");
    Map resultMap = this.dataCollectCompanyWriteService.releaseJob(cb21Vo);
    setData("data", resultMap);
    return getResult();
  }
  
  private void dznumCheck(Object dznum) {
    String regex = "650[0-9]0{8}";
    AppAssert.notEmpty(dznum, "数据归集地州区划编码不能为空");
    AppAssert.isTrue(dznum.toString().matches("650[0-9]0{8}"), "数据归集地州区划编码格式错误");
  }
  
  private void checkNotNull(Object object) {
    ValidatorFactory validatorFactory = Validation.buildDefaultValidatorFactory();
    Validator validator = validatorFactory.getValidator();
    Set<ConstraintViolation<Object>> validate = validator.validate(object, new Class[0]);
    if (CollectionUtils.isNotEmpty(validate))
      throw new BusinessException((String)validate.stream().map(ConstraintViolation::getMessage).collect(Collectors.joining(","))); 
  }
  
  public static void main(String[] args) {
    Map<Object, Object> map = new HashMap<>();
    map.put("phone_mob", "18682739320");
    String jsonStr = JsonFactory.bean2json(map);
    System.out.println(jsonStr);
    String encrypt = Sm2Util.encrypt(Sm2Util.pem2PublicKey("/sm2/pub.key.pem"), jsonStr);
    System.out.println(encrypt);
    String dData = "BMhw3MApZ5BP3i5URSkjI2h0rVcI/rgsRbp91iSevxm80VMrTkWEgTq2ukevyAgf7Ia7B7pB3Ud8UFnn7ympSGmN2ruBcas6UkB/RGe+KqZtri4HhWXzk/H/Z/nUgZlBWHIxYWguasVT/dnXoslOuT4o+NGf8iv/hqLAULLFsmcXxk7/VqGN";
    String decrypt = Sm2Util.decrypt(Sm2Util.pem2PrivateKey("/sm2/pri.key.pem"), dData);
    System.out.println(decrypt);
    String regex = "650[0-9]0{8}";
    String testCase = "650100000000";
    boolean isValid = testCase.matches(regex);
    System.out.println(testCase + " is valid: " + isValid);
  }
}
